# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeJobData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'stress': 'JobDataStressTest',
        'continuous_inc': 'JobDataContinuousIncrementalTest',
        'file_scan': 'JobDataScan',
        'cross_plane_res': 'CrossplanetaskCrossPlaneResponse',
        'generative_model': 'JobDataGenerativeModelTest'
    }

    attribute_map = {
        'stress': 'stress',
        'continuous_inc': 'continuousInc',
        'file_scan': 'fileScan',
        'cross_plane_res': 'crossPlaneRes',
        'generative_model': 'generativeModel'
    }

    def __init__(self, stress=None, continuous_inc=None, file_scan=None, cross_plane_res=None, generative_model=None):  # noqa: E501
        """RimeJobData - a model defined in Swagger"""  # noqa: E501
        self._stress = None
        self._continuous_inc = None
        self._file_scan = None
        self._cross_plane_res = None
        self._generative_model = None
        self.discriminator = None
        if stress is not None:
            self.stress = stress
        if continuous_inc is not None:
            self.continuous_inc = continuous_inc
        if file_scan is not None:
            self.file_scan = file_scan
        if cross_plane_res is not None:
            self.cross_plane_res = cross_plane_res
        if generative_model is not None:
            self.generative_model = generative_model

    @property
    def stress(self):
        """Gets the stress of this RimeJobData.  # noqa: E501


        :return: The stress of this RimeJobData.  # noqa: E501
        :rtype: JobDataStressTest
        """
        return self._stress

    @stress.setter
    def stress(self, stress):
        """Sets the stress of this RimeJobData.


        :param stress: The stress of this RimeJobData.  # noqa: E501
        :type: JobDataStressTest
        """

        self._stress = stress

    @property
    def continuous_inc(self):
        """Gets the continuous_inc of this RimeJobData.  # noqa: E501


        :return: The continuous_inc of this RimeJobData.  # noqa: E501
        :rtype: JobDataContinuousIncrementalTest
        """
        return self._continuous_inc

    @continuous_inc.setter
    def continuous_inc(self, continuous_inc):
        """Sets the continuous_inc of this RimeJobData.


        :param continuous_inc: The continuous_inc of this RimeJobData.  # noqa: E501
        :type: JobDataContinuousIncrementalTest
        """

        self._continuous_inc = continuous_inc

    @property
    def file_scan(self):
        """Gets the file_scan of this RimeJobData.  # noqa: E501


        :return: The file_scan of this RimeJobData.  # noqa: E501
        :rtype: JobDataScan
        """
        return self._file_scan

    @file_scan.setter
    def file_scan(self, file_scan):
        """Sets the file_scan of this RimeJobData.


        :param file_scan: The file_scan of this RimeJobData.  # noqa: E501
        :type: JobDataScan
        """

        self._file_scan = file_scan

    @property
    def cross_plane_res(self):
        """Gets the cross_plane_res of this RimeJobData.  # noqa: E501


        :return: The cross_plane_res of this RimeJobData.  # noqa: E501
        :rtype: CrossplanetaskCrossPlaneResponse
        """
        return self._cross_plane_res

    @cross_plane_res.setter
    def cross_plane_res(self, cross_plane_res):
        """Sets the cross_plane_res of this RimeJobData.


        :param cross_plane_res: The cross_plane_res of this RimeJobData.  # noqa: E501
        :type: CrossplanetaskCrossPlaneResponse
        """

        self._cross_plane_res = cross_plane_res

    @property
    def generative_model(self):
        """Gets the generative_model of this RimeJobData.  # noqa: E501


        :return: The generative_model of this RimeJobData.  # noqa: E501
        :rtype: JobDataGenerativeModelTest
        """
        return self._generative_model

    @generative_model.setter
    def generative_model(self, generative_model):
        """Sets the generative_model of this RimeJobData.


        :param generative_model: The generative_model of this RimeJobData.  # noqa: E501
        :type: JobDataGenerativeModelTest
        """

        self._generative_model = generative_model

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeJobData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeJobData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GenerativetestingObjectiveSubCategory(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    UNSPECIFIED = "OBJECTIVE_SUB_CATEGORY_UNSPECIFIED"
    THEFT = "OBJECTIVE_SUB_CATEGORY_THEFT"
    POISONING = "OBJECTIVE_SUB_CATEGORY_POISONING"
    VIOLENCE = "OBJECTIVE_SUB_CATEGORY_VIOLENCE"
    STALKING = "OBJECTIVE_SUB_CATEGORY_STALKING"
    TERRORISM = "OBJECTIVE_SUB_CATEGORY_TERRORISM"
    BOMB = "OBJECTIVE_SUB_CATEGORY_BOMB"
    MURDER = "OBJECTIVE_SUB_CATEGORY_MURDER"
    PII_SSN = "OBJECTIVE_SUB_CATEGORY_PII_SSN"
    PII_PHONE_NUMBER = "OBJECTIVE_SUB_CATEGORY_PII_PHONE_NUMBER"
    PII_CREDIT_CARD = "OBJECTIVE_SUB_CATEGORY_PII_CREDIT_CARD"
    PII_EMAIL_ADDRESS = "OBJECTIVE_SUB_CATEGORY_PII_EMAIL_ADDRESS"
    PII_PASSPORT_NUMBER = "OBJECTIVE_SUB_CATEGORY_PII_PASSPORT_NUMBER"
    PIRACY = "OBJECTIVE_SUB_CATEGORY_PIRACY"
    HACKING = "OBJECTIVE_SUB_CATEGORY_HACKING"
    VIRUS = "OBJECTIVE_SUB_CATEGORY_VIRUS"
    MISINFORMATION = "OBJECTIVE_SUB_CATEGORY_MISINFORMATION"
    FINANCIAL_ADVICE = "OBJECTIVE_SUB_CATEGORY_FINANCIAL_ADVICE"
    PII = "OBJECTIVE_SUB_CATEGORY_PII"
    PROMPT_EXTRACTION = "OBJECTIVE_SUB_CATEGORY_PROMPT_EXTRACTION"
    FINANCIAL = "OBJECTIVE_SUB_CATEGORY_FINANCIAL"
    COPYRIGHT_EXTRACTION = "OBJECTIVE_SUB_CATEGORY_COPYRIGHT_EXTRACTION"
    LONG_PROMPTS = "OBJECTIVE_SUB_CATEGORY_LONG_PROMPTS"
    CHILD_PORN = "OBJECTIVE_SUB_CATEGORY_CHILD_PORN"
    DRUGS = "OBJECTIVE_SUB_CATEGORY_DRUGS"
    SUICIDE = "OBJECTIVE_SUB_CATEGORY_SUICIDE"
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
    }

    attribute_map = {
    }

    def __init__(self):  # noqa: E501
        """GenerativetestingObjectiveSubCategory - a model defined in Swagger"""  # noqa: E501
        self.discriminator = None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GenerativetestingObjectiveSubCategory, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GenerativetestingObjectiveSubCategory):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeCreateUserRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'email': 'str',
        'password': 'str',
        'full_name': 'str',
        'org_role': 'RimeActorRole'
    }

    attribute_map = {
        'email': 'email',
        'password': 'password',
        'full_name': 'fullName',
        'org_role': 'orgRole'
    }

    def __init__(self, email=None, password=None, full_name=None, org_role=None):  # noqa: E501
        """RimeCreateUserRequest - a model defined in Swagger"""  # noqa: E501
        self._email = None
        self._password = None
        self._full_name = None
        self._org_role = None
        self.discriminator = None
        self.email = email
        self.password = password
        self.full_name = full_name
        if org_role is not None:
            self.org_role = org_role

    @property
    def email(self):
        """Gets the email of this RimeCreateUserRequest.  # noqa: E501

        The email address of the user.  # noqa: E501

        :return: The email of this RimeCreateUserRequest.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this RimeCreateUserRequest.

        The email address of the user.  # noqa: E501

        :param email: The email of this RimeCreateUserRequest.  # noqa: E501
        :type: str
        """
        if email is None:
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    @property
    def password(self):
        """Gets the password of this RimeCreateUserRequest.  # noqa: E501

        The password of the user. This password will be changed on the first login.  # noqa: E501

        :return: The password of this RimeCreateUserRequest.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this RimeCreateUserRequest.

        The password of the user. This password will be changed on the first login.  # noqa: E501

        :param password: The password of this RimeCreateUserRequest.  # noqa: E501
        :type: str
        """
        if password is None:
            raise ValueError("Invalid value for `password`, must not be `None`")  # noqa: E501

        self._password = password

    @property
    def full_name(self):
        """Gets the full_name of this RimeCreateUserRequest.  # noqa: E501

        The full name of the user.  # noqa: E501

        :return: The full_name of this RimeCreateUserRequest.  # noqa: E501
        :rtype: str
        """
        return self._full_name

    @full_name.setter
    def full_name(self, full_name):
        """Sets the full_name of this RimeCreateUserRequest.

        The full name of the user.  # noqa: E501

        :param full_name: The full_name of this RimeCreateUserRequest.  # noqa: E501
        :type: str
        """
        if full_name is None:
            raise ValueError("Invalid value for `full_name`, must not be `None`")  # noqa: E501

        self._full_name = full_name

    @property
    def org_role(self):
        """Gets the org_role of this RimeCreateUserRequest.  # noqa: E501


        :return: The org_role of this RimeCreateUserRequest.  # noqa: E501
        :rtype: RimeActorRole
        """
        return self._org_role

    @org_role.setter
    def org_role(self, org_role):
        """Sets the org_role of this RimeCreateUserRequest.


        :param org_role: The org_role of this RimeCreateUserRequest.  # noqa: E501
        :type: RimeActorRole
        """

        self._org_role = org_role

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeCreateUserRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeCreateUserRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeRegisterDatasetResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dataset_id': 'str',
        'registry_validation_job_id': 'RimeUUID'
    }

    attribute_map = {
        'dataset_id': 'datasetId',
        'registry_validation_job_id': 'registryValidationJobId'
    }

    def __init__(self, dataset_id=None, registry_validation_job_id=None):  # noqa: E501
        """RimeRegisterDatasetResponse - a model defined in Swagger"""  # noqa: E501
        self._dataset_id = None
        self._registry_validation_job_id = None
        self.discriminator = None
        if dataset_id is not None:
            self.dataset_id = dataset_id
        if registry_validation_job_id is not None:
            self.registry_validation_job_id = registry_validation_job_id

    @property
    def dataset_id(self):
        """Gets the dataset_id of this RimeRegisterDatasetResponse.  # noqa: E501

        dataset_id is a string as it contains semantic meaning and does not adhere to UUID standard.  # noqa: E501

        :return: The dataset_id of this RimeRegisterDatasetResponse.  # noqa: E501
        :rtype: str
        """
        return self._dataset_id

    @dataset_id.setter
    def dataset_id(self, dataset_id):
        """Sets the dataset_id of this RimeRegisterDatasetResponse.

        dataset_id is a string as it contains semantic meaning and does not adhere to UUID standard.  # noqa: E501

        :param dataset_id: The dataset_id of this RimeRegisterDatasetResponse.  # noqa: E501
        :type: str
        """

        self._dataset_id = dataset_id

    @property
    def registry_validation_job_id(self):
        """Gets the registry_validation_job_id of this RimeRegisterDatasetResponse.  # noqa: E501


        :return: The registry_validation_job_id of this RimeRegisterDatasetResponse.  # noqa: E501
        :rtype: RimeUUID
        """
        return self._registry_validation_job_id

    @registry_validation_job_id.setter
    def registry_validation_job_id(self, registry_validation_job_id):
        """Sets the registry_validation_job_id of this RimeRegisterDatasetResponse.


        :param registry_validation_job_id: The registry_validation_job_id of this RimeRegisterDatasetResponse.  # noqa: E501
        :type: RimeUUID
        """

        self._registry_validation_job_id = registry_validation_job_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeRegisterDatasetResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeRegisterDatasetResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
